==> paragui-0.6.4.tgz: include/paragui/parastretch.h <==
/*
    parastretch - image stretching functions
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2000/09/30 16:30:19 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/parastretch.h,v $
    CVS/RCS Revision: $Revision: 1.3 $
    Status:           $State: Exp $
*/

#ifndef PARASTRETCH_H
#define PARASTRETCH_H

#include "SDL.h"

#define sign(x) ((x)>0 ? 1:-1)

void CreateFilterLUT();
void RectStretch(SDL_Surface* src_surface, int xs1, int ys1, int xs2, int ys2, SDL_Surface* dst_surface, int xd1, int yd1, int xd2, int yd2, Uint32* voiLUT);
//void Stretch(SDL_Surface* src_surface, SDL_Surface* dst_surface, long x1,long x2,long y1,long y2,long yr,long yw);
SDL_Surface* SDLCopyRect(SDL_Surface* s, int x, int y, int w, int h);
void SDLSmoothFast(SDL_Surface* src, SDL_Surface* dst);
void InterpolatePixel(SDL_Surface* src, SDL_Surface* dest);

void SDL_FillRectEx(SDL_Surface *dst, Uint16 x0, Uint16 y0, Uint16 x1, Uint16 y1, Uint32 color);

#ifndef M_PI
#define M_PI      3.14159265358979323846
#endif

#endif // PARASTRETCH_H

==> paragui-0.7.2p1.tgz: include/paragui/parastretch.h <==
/*
    parastretch - image stretching functions
    Copyright (C) 2000,2001  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/04/24 16:51:08 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/include/Attic/parastretch.h,v $
    CVS/RCS Revision: $Revision: 1.1.2.1 $
    Status:           $State: Exp $
*/

#ifndef PARASTRETCH_H
#define PARASTRETCH_H

#include "SDL.h"

// the whole thing has to be cleaned up :(

void CreateFilterLUT();
void RectStretch(SDL_Surface* src_surface, int xs1, int ys1, int xs2, int ys2, SDL_Surface* dst_surface, int xd1, int yd1, int xd2, int yd2, Uint32* voiLUT);
//void Stretch(SDL_Surface* src_surface, SDL_Surface* dst_surface, long x1,long x2,long y1,long y2,long yr,long yw);
SDL_Surface* PG_CopyRect(SDL_Surface* s, int x, int y, int w, int h);
void PG_SmoothFast(SDL_Surface* src, SDL_Surface* dst);
void InterpolatePixel(SDL_Surface* src, SDL_Surface* dest);

void SDL_FillRectEx(SDL_Surface *dst, Uint16 x0, Uint16 y0, Uint16 x1, Uint16 y1, Uint32 color);

#ifndef M_PI
#define M_PI      3.14159265358979323846
#endif

#endif // PARASTRETCH_H
